==> owlapi-parsers-3.4.1-sources.jar: org/coode/owlapi/obo/parser/RawFrameHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, The University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.obo.parser;

import java.util.ArrayList;
import java.util.List;

/**
 * Author: Matthew Horridge<br>
 * Stanford University<br>
 * Bio-Medical Informatics Research Group<br>
 * Date: 19/04/2012
 */
public class RawFrameHandler implements OBOParserHandler {

    private String currentFrameType;
    
    private List<OBOTagValuePair> currentTagValuePairs = new ArrayList<OBOTagValuePair>();
    
    private OBOFrame headerFrame;
    
    private List<OBOFrame> typeDefFrames = new ArrayList<OBOFrame>();
    
    private List<OBOFrame> nonTypeDefFrames = new ArrayList<OBOFrame>();
    
    public void startHeader() {
        currentTagValuePairs.clear();
    }

    public void endHeader() {
        headerFrame = new OBOFrame(currentTagValuePairs);
    }

    public void startFrame(String frameType) {
        currentFrameType = frameType;
        currentTagValuePairs.clear();
    }

    public void endFrame() {
        storeCurrentFrame();
    }

    private OBOFrame storeCurrentFrame() {
        OBOFrame frame = new OBOFrame(currentFrameType, currentTagValuePairs);
        if(frame.isTypeDefFrame()) {
            typeDefFrames.add(frame);
        }
        else {
            nonTypeDefFrames.add(frame);
        }
        return frame;
    }

    public void handleTagValue(String tag, String value, String qualifierBlock, String comment) {
        OBOTagValuePair tvp = new OBOTagValuePair(tag, value, qualifierBlock, comment);
        currentTagValuePairs.add(tvp);
    }

    public OBOFrame getHeaderFrame() {
        return headerFrame;
    }


    public List<OBOFrame> getTypeDefFrames() {
        return typeDefFrames;
    }

    public List<OBOFrame> getNonTypeDefFrames() {
        return nonTypeDefFrames;
    }
}

==> owlapi-parsers-3.4.2-sources.jar: org/coode/owlapi/obo/parser/RawFrameHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, The University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.obo.parser;

import java.util.ArrayList;
import java.util.List;

/**
 * Author: Matthew Horridge<br>
 * Stanford University<br>
 * Bio-Medical Informatics Research Group<br>
 * Date: 19/04/2012
 */
public class RawFrameHandler implements OBOParserHandler {

    private String currentFrameType;
    
    private List<OBOTagValuePair> currentTagValuePairs = new ArrayList<OBOTagValuePair>();
    
    private OBOFrame headerFrame;
    
    private List<OBOFrame> typeDefFrames = new ArrayList<OBOFrame>();
    
    private List<OBOFrame> nonTypeDefFrames = new ArrayList<OBOFrame>();
    
    @Override
    public void startHeader() {
        currentTagValuePairs.clear();
    }

    @Override
    public void endHeader() {
        headerFrame = new OBOFrame(currentTagValuePairs);
    }

    @Override
    public void startFrame(String frameType) {
        currentFrameType = frameType;
        currentTagValuePairs.clear();
    }

    @Override
    public void endFrame() {
        storeCurrentFrame();
    }

    private OBOFrame storeCurrentFrame() {
        OBOFrame frame = new OBOFrame(currentFrameType, currentTagValuePairs);
        if(frame.isTypeDefFrame()) {
            typeDefFrames.add(frame);
        }
        else {
            nonTypeDefFrames.add(frame);
        }
        return frame;
    }

    @Override
    public void handleTagValue(String tag, String value, String qualifierBlock, String comment) {
        OBOTagValuePair tvp = new OBOTagValuePair(tag, value, qualifierBlock, comment);
        currentTagValuePairs.add(tvp);
    }

    /** @return the header frame */
    public OBOFrame getHeaderFrame() {
        return headerFrame;
    }


    /** @return the typedef frames */
    public List<OBOFrame> getTypeDefFrames() {
        return typeDefFrames;
    }

    /** @return the non typedef frames */
    public List<OBOFrame> getNonTypeDefFrames() {
        return nonTypeDefFrames;
    }
}
